## ----setup, include=FALSE-----------------------------------------------------
library(kirby21.t1)
library(fslr)
library(neurobase)
library(extrantsr)
knitr::opts_chunk$set(echo = TRUE, comment = "")

## ---- eval = FALSE------------------------------------------------------------
#  packages = installed.packages()
#  packages = packages[, "Package"]
#  if (!"kirby21.t1" %in% packages) {
#    devtools::install_github("muschellij2/kirby21.t1")
#  }

## ----data---------------------------------------------------------------------
library(kirby21.t1)
t1_fname = get_t1_filenames(
  ids = 113, 
  visits = 1)
if (is.null(t1_fname)) {
  dl = TRUE
} else {
  dl = !file.exists(t1_fname)
}
if (dl) {
  url = paste0("https://raw.githubusercontent.com/muschellij2/kirby21.t1", "/master/inst/visit_1/113/113-01-T1.nii.gz")
  t1_fname = tempfile(fileext = ".nii.gz")
  download.file(url, t1_fname)
}

## ----t1_plot------------------------------------------------------------------
t1 = readnii(t1_fname)
ortho2(t1)

## ----t1_naive_ss, cache = FALSE-----------------------------------------------
if (have.fsl()) {
  ss_naive = fslbet(infile = t1_fname)
}

## ----t1_naive_plot, cache = FALSE---------------------------------------------
if (have.fsl()) {
  ortho2(ss_naive)
}


## ----t1_ss, cache = FALSE-----------------------------------------------------
n4img = bias_correct(
  t1_fname, 
  correction = "N4", 
  retimg = FALSE,
  outfile = tempfile(fileext = ".nii.gz"),
  verbose = FALSE)
if (have.fsl()) {
  template.file = fslr::mni_fname(brain = TRUE)
  template.mask = fslr::mni_fname(brain = TRUE, mask = TRUE)
  removed_neck = extrantsr::double_remove_neck(
    n4img,
    template.file = template.file,
    template.mask = template.mask)
  ortho2(removed_neck)
  double_ortho(t1, removed_neck)
}

## ---- echo = TRUE, eval = FALSE-----------------------------------------------
#  if (have.fsl()) {
#    ss = extrantsr::fslbet_robust(t1_fname,
#      remover = "double_remove_neck", recog = FALSE)
#    ortho2(ss)
#  }

## ---- echo = FALSE, eval = TRUE-----------------------------------------------
if (have.fsl()) {
  ss = fslbet(removed_neck, retimg = TRUE, verbose = FALSE)
  ortho2(ss)
}

## ----t1_ss_plot2, cache = FALSE-----------------------------------------------
if (have.fsl()) {
  alpha = function(col, alpha = 1) {
    cols = t(col2rgb(col, alpha = FALSE)/255)
    rgb(cols, alpha = alpha)
  }      
  ortho2(t1, ss > 0, col.y = alpha("red", 0.5))
}

## ----t1_ss_red, cache = FALSE-------------------------------------------------
if (have.fsl()) {
  ss_red = dropEmptyImageDimensions(ss)
  ortho2(ss_red)
}

